@@ -5,7 +5,7 @@ from typing import List, Union
 from pathlib import Path
 
 
-__version__ = "2022.6.13.1"
+__version__ = "2022.6.22.1"
 log_format = logging.Formatter(
     "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
@@ -53,6 +53,8 @@ def configure_logger(
     log_file: Union[Path, str] = None,
     append: bool = True,
     caller_info: dict = None,
+    unify_level: bool = True,
+    fmt: logging.Formatter = None,
 ):
     """配置日志处理器
     :param level: int, 指定日志级别
@@ -60,12 +62,14 @@ def configure_logger(
     :param log_file: 日志文件存储路径
     :param append: 是否为追加模式。当为覆盖模式时会清空已有的handler再添加新的
     :param caller_info: 调用源信息
+    :param unify_level: 统一日志级别，为True时各Handler与logger都采用统一的level
+    :param fmt: 重置日志输出格式
     """
     from deng.utils import get_caller_info
     _info = caller_info or get_caller_info(2)
-    logger.info(f"调用来源：{_info['output']}")
+    logger.debug(f"调用来源：{_info['output']}")
 
-    # 设置日志级别
+    # 设置主句柄日志级别
     if level in (
         logging.NOTSET,
         logging.DEBUG,
@@ -77,8 +81,16 @@ def configure_logger(
         logger.setLevel(level)
     else:
         raise ValueError(f"level参数非法：{level}")
-    for handler in logger.handlers:
-        handler.setLevel(level)
+
+    # 重置日志处理器输出格式
+    if fmt and isinstance(fmt, logging.Formatter):
+        for handler in logger.handlers:
+            handler.setFormatter(fmt)
+
+    # 各Handler与Logger采用统一的level级别
+    if unify_level:
+        for handler in logger.handlers:
+            handler.setLevel(level)
 
     # 非追加模式时，先清空所有已有的handler
     # 必须放置在设置已有Handler日志级别之后，因为已有的Handler可能被别处引用
@@ -97,21 +109,23 @@ def configure_logger(
         for handler in handlers:
             # 判断是否重复
             if handler in logger.handlers:
-                logger.warning(f"日志处理器已经存在，忽略：{handler}")
+                logger.debug(f"日志处理器已经存在，忽略：{handler}")
                 continue
 
             # StreamHandler 类型的处理器只保留一个
             if type(handler) == logging.StreamHandler:
-                logger.warning(f"StreamHandler 类型处理器已经存在（控制台只保留一个），忽略：{handler}")
+                logger.debug(f"StreamHandler 类型处理器已经存在（控制台只保留一个），忽略：{handler}")
                 continue
 
             # FileHandler 类型处理器不重复，输出到同一目的地的只保留一个
             if isinstance(handler, logging.FileHandler):
                 if str(handler.baseFilename) in log_file_list:
-                    logger.warning(f"已经有一个相同目的地的处理器，忽略：{handler}")
+                    logger.debug(f"已经有一个相同目的地的处理器，忽略：{handler}")
                     continue
                 else:
-                    handler.setLevel(level)
+                    # 各Handler与Logger采用统一的level级别
+                    if unify_level:
+                        handler.setLevel(level)
                     logger.addHandler(handler)
                     log_file_list.append(str(handler.baseFilename))
             elif isinstance(handler, logging.Handler):
@@ -121,7 +135,7 @@ def configure_logger(
 
     if log_file:
         if str(log_file) in log_file_list:
-            logger.warning(f"已经有一个相同目的地的处理器，忽略：{log_file}")
+            logger.debug(f"已经有一个相同目的地的处理器，忽略：{log_file}")
         else:
             log_file = Path(log_file)
             if not log_file.parent.exists():
